==> ksystemlog_15.12.3.orig.tar.xz: ksystemlog-15.12.3/src/modes/xorg/xorgLogMode.h <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef _XORG_LOG_MODE_H_
#define _XORG_LOG_MODE_H_

/**
 * Xorg Log Mode Identifier
 */
#define XORG_LOG_MODE_ID "xorgLogMode"

/**
 * Xorg Log Icon
 */
#define XORG_MODE_ICON "xorg"

#include <QList>

#include "logFile.h"

#include "logMode.h"

class XorgLogMode : public LogMode
{
    Q_OBJECT

public:
    explicit XorgLogMode();

    ~XorgLogMode();

    Analyzer *createAnalyzer(const QVariant &options = QVariant());

    QList<LogFile> createLogFiles();
};

#endif // _XORG_LOG_MODE_H_

==> ksystemlog-18.07.80.tar.xz: ksystemlog-18.07.80/src/modes/xorg/xorgLogMode.h <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef _XORG_LOG_MODE_H_
#define _XORG_LOG_MODE_H_

/**
 * Xorg Log Mode Identifier
 */
#define XORG_LOG_MODE_ID "xorgLogMode"

/**
 * Xorg Log Icon
 */
#define XORG_MODE_ICON "xorg"

#include <QList>

#include "logFile.h"

#include "logMode.h"

class XorgLogMode : public LogMode
{
    Q_OBJECT

public:
    explicit XorgLogMode();

    ~XorgLogMode();

    Analyzer *createAnalyzer(const QVariant &options = QVariant()) Q_DECL_OVERRIDE;

    QList<LogFile> createLogFiles() Q_DECL_OVERRIDE;
};

#endif // _XORG_LOG_MODE_H_
